Module token

Module token 

Capability token types and operations

Implements UCAN-inspired delegatable tokens where each token in a delegation chain can only narrow (attenuate) scopes, never widen.

Structs

CapabilityToken
A CLASP capability token.
ProofLink
A link in the proof/delegation chain

Constants

TOKEN_PREFIX
Token prefix

Functions

pattern_is_subset
Check if child pattern is a subset of parent pattern.